@@ -9,7 +9,7 @@ use vars qw(@ISA $VERSION);
 use Carp;
 
 @ISA = qw(Games::Bingo);
-$VERSION = '0.17';
+$VERSION = '0.18';
 
 sub new {
 	my $class = shift;
@@ -259,22 +259,19 @@ Returns the number of columns in G::B::Column object.
 The TODO file contains a complete list for the whole Games::Bingo
 project.
 
-=head1 AUTHOR
-
-jonasbn E<lt>jonasbn@cpan.orgE<gt>
-
 =head1 ACKNOWLEDGEMENTS
 
 My friend Allan helped me out with some of the algoritmic stuff and was
 in when this class was thought up.
 
+=head1 AUTHOR
+
+Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
+
 =head1 COPYRIGHT
 
-Games::Bingo and related modules are free software and is released under
-the Artistic License. See
-E<lt>http://www.perl.com/language/misc/Artistic.htmlE<gt> for details.
+Games-Bingo is (C) by Jonas B. Nielsen, (jonasbn) 2003-2015
 
-Games::Bingo is (C) 2003-2004 Jonas B. Nielsen (jonasbn)
-E<lt>jonasbn@cpan.orgE<gt>
+Games-Bingo is released under the artistic license 2.0
 
-=cut
+=cut
\ No newline at end of file
